#define DECLARE_TEXTURE(Name, index) \
    texture Name: register(t##index); \
    sampler Name##Sampler: register(s##index)

#define SAMPLE_TEXTURE(Name, texCoord) tex2D(Name##Sampler, texCoord)

uniform float Time; // level.TimeActive
uniform float2 CamPos; // level.Camera.Position
uniform float2 Dimensions; // new Vector2(320, 180)

uniform float4x4 TransformMatrix;
uniform float4x4 ViewMatrix;

DECLARE_TEXTURE(text, 0);

float length(float2 pos) {
    return sqrt(pos.x * pos.x + pos.y * pos.y);
}

float4 SpritePixelShader(float2 uv : TEXCOORD0) : COLOR0
{
    float2 newuv = ((uv + uv * sin(uv/2000.)) * 1.5);
    float2 worldPos = (newuv * Dimensions) + CamPos;
    float4 color = SAMPLE_TEXTURE(text, newuv);

    color.r *= length(worldPos) % 32. / 32.;

    return color;
}

void SpriteVertexShader(inout float4 color    : COLOR0,
                        inout float2 texCoord : TEXCOORD0,
                        inout float4 position : SV_Position)
{
    position = mul(position, ViewMatrix);
    position = mul(position, TransformMatrix);
}

technique Shader
{
    pass pass0
    {
        VertexShader = compile vs_3_0 SpriteVertexShader();
        PixelShader = compile ps_3_0 SpritePixelShader();
    }
}